@@ -1,5 +1,5 @@
 import os, sys, json
-from python_helper.api.src.service import StringHelper, LogHelper, ObjectHelper
+from python_helper.api.src.service import StringHelper, LogHelper, ObjectHelper, SettingHelper
 from python_helper.api.src.domain import Constant as c
 
 OS = os
@@ -8,12 +8,14 @@ OS_SEPARATOR = OS.path.sep
 
 clear = lambda: OS.system('cls')
 
-def getEnvironmentValue(environmentKey, default=None) :
-    environmentValue = OS.environ.get(environmentKey) if not environmentKey is None else default
-    return environmentValue if not environmentValue is None else default
+def getEnvironmentValue(environmentKey, default=None, avoidRecursiveCall=False) :
+    environmentValue = default if ObjectHelper.isNone(environmentKey) else OS.environ.get(environmentKey)
+    return environmentValue if ObjectHelper.isNotNone(environmentValue) else default
 
-def setEnvironmentValue(environmentKey, environmentValue, default=None) :
+def updateEnvironmentValue(environmentKey, environmentValue, default=None, avoidRecursiveCall=False) :
     if ObjectHelper.isNotEmpty(environmentKey) :
+        if SettingHelper.ACTIVE_ENVIRONMENT == environmentKey and not avoidRecursiveCall :
+            return SettingHelper.updateActiveEnvironment(environmentValue)
         associatedValue = None
         if not environmentValue is None :
             associatedValue = str(StringHelper.filterString(environmentValue))
@@ -25,43 +27,43 @@ def setEnvironmentValue(environmentKey, environmentValue, default=None) :
             try:
                 deleteEnvironmentValue(environmentKey)
             except Exception as exception :
-                LogHelper.log(setEnvironmentValue, f'Failed to delete "{environmentKey}" enviroment variable key', exception=exception)
+                LogHelper.warning(updateEnvironmentValue, f'Failed to delete "{environmentKey}" enviroment variable key', exception=exception)
         return associatedValue
     else :
-        LogHelper.debug(setEnvironmentValue, f'arguments: environmentKey: {environmentKey}, environmentValue: {environmentValue}, default: {default}')
+        LogHelper.debug(updateEnvironmentValue, f'arguments: environmentKey: {environmentKey}, environmentValue: {environmentValue}, default: {default}')
         raise Exception(f'Error associating environment variable "{environmentKey}" key to environment variable "{environmentValue}" value')
 
-def replaceEnvironmentVariable(environmentKey, environmentValue, default=None) :
+def replaceEnvironmentVariable(environmentKey, environmentValue, default=None, avoidRecursiveCall=False) :
     originalEnvironmentValue = getEnvironmentValue(environmentKey, default=default)
-    setEnvironmentValue(environmentKey, environmentValue, default=default)
+    updateEnvironmentValue(environmentKey, environmentValue, default=default)
     return originalEnvironmentValue
 
-def resetEnvironmentVariables(environmentVariables, originalEnvironmentVariables) :
+def resetEnvironmentVariables(environmentVariables, originalEnvironmentVariables, avoidRecursiveCall=False) :
     if environmentVariables :
         for key in environmentVariables.keys() :
             if key in originalEnvironmentVariables :
-                setEnvironmentValue(key, originalEnvironmentVariables[key])
+                updateEnvironmentValue(key, originalEnvironmentVariables[key])
 
-def deleteEnvironmentValue(environmentKey) :
-    if not environmentKey is None :
+def deleteEnvironmentValue(environmentKey, avoidRecursiveCall=False) :
+    if ObjectHelper.isNotNone(environmentKey) :
         OS.environ.pop(environmentKey)
 
-def getActiveEnvironmentVariableSet() :
+def getActiveEnvironmentVariableSet(avoidRecursiveCall=False) :
     try :
         return json.loads(str(OS.environ)[8:-1].replace(c.DOUBLE_QUOTE, c.BACK_SLASH_DOUBLE_QUOTE).replace(c.SINGLE_QUOTE, c.DOUBLE_QUOTE))
     except Exception as exception :
         LogHelper.error(getActiveEnvironmentVariableSet, 'Not possible to load os.environ as a json. Returning os.environ as string by default', exception)
         return str(OS.environ)[8:-1]
 
-def listDirectoryContent() :
+def listDirectoryContent(avoidRecursiveCall=False) :
     return OS.listdir(apisPath)
 
-def appendPath(path) :
+def appendPath(path, avoidRecursiveCall=False) :
     SYS.path.append(path)
 
-def getCurrentSoutStatus() :
+def getCurrentSoutStatus(avoidRecursiveCall=False) :
     return SYS.stdout, SYS.stderr
 
-def overrideSoutStatus(stdout, stderr) :
+def overrideSoutStatus(stdout, stderr, avoidRecursiveCall=False) :
     SYS.stdout = stdout
     SYS.stderr = stderr
