@@ -2,9 +2,18 @@ from python_helper.api.src.domain  import Constant as c
 from python_helper.api.src.service import LogHelper, ObjectHelper, StringHelper, RandomHelper
 
 MAXIMUN_ARGUMENTS = 20
+
+CLASS_TYPE_NAME = 'class'
+METHOD_TYPE_NAME = 'method'
+BUILTIN_FUNCTION_OR_METHOD_TYPE_NAME = 'builtin_function_or_method'
+FUNCTION_TYPE_NAME = 'function'
+
+UNKNOWN_TYPE_NAME = 'unknown type'
+NAME_NOT_PRESENT = 'name not present'
+
 METHOD_TYPE_NAME_LIST = [
-    'method',
-    'builtin_function_or_method'
+    METHOD_TYPE_NAME,
+    BUILTIN_FUNCTION_OR_METHOD_TYPE_NAME
 ]
 
 def getAttributeOrMethod(instance, name) :
@@ -12,7 +21,7 @@ def getAttributeOrMethod(instance, name) :
     try :
         attributeOrMethodInstance = None if ObjectHelper.isNone(instance) or ObjectHelper.isNone(name) else getattr(instance, name)
     except Exception as exception :
-        LogHelper.warning(getAttributeOrMethod, f'Not possible to get "{name}" from "{instance.__class__.__name__ if ObjectHelper.isNotNone(instance) else instance}" instance')
+        LogHelper.warning(getAttributeOrMethod, f'Not possible to get "{name}" from "{getName(instance.__class__, typeName=CLASS_TYPE_NAME) if ObjectHelper.isNotNone(instance) else instance}" instance', exception=exception)
     return attributeOrMethodInstance
 
 def getAttributeAndMethodNameList(instanceClass) :
@@ -43,7 +52,7 @@ def getMethodNameList(instanceClass) :
     ]
 
 def isMethodInstance(methodInstance) :
-    return methodInstance.__class__.__name__ in METHOD_TYPE_NAME_LIST if ObjectHelper.isNotNone(methodInstance) else False
+    return getName(methodInstance.__class__) in METHOD_TYPE_NAME_LIST if ObjectHelper.isNotNone(methodInstance) else False
 
 def isNotMethodInstance(methodInstance) :
     return not isMethodInstance(methodInstance)
@@ -89,26 +98,11 @@ def getArgsOrder(targetClass) :
                 argsOrderDictionary[strArgs.index(value)] = key
         argsOrder = [argsOrderDictionary[key] for key in sorted(argsOrderDictionary)]
     except Exception as exception :
-        errorMessage = f'Not possible to get args order from "{targetClass.__name__}" target class'
+        errorMessage = f'Not possible to get args order from "{getName(targetClass)}" target class'
         LogHelper.error(getArgsOrder, errorMessage, exception)
         raise Exception(errorMessage)
     return argsOrder
 
-    #
-    #
-    #
-    # args = []
-    # objectInstance = None
-    # for _ in range(MAXIMUN_ARGUMENTS) :
-    #     try :
-    #         objectInstance = instanceClass(*args)
-    #         break
-    #     except :
-    #         args.append(None)
-    # if not isinstance(objectInstance, instanceClass) :
-    #     raise Exception(f'Not possible to instanciate {instanceClass} class in instanciateItWithNoArgsConstructor() method with None as args constructor')
-    return targetClass
-
 def isNotPrivate(attributeOrMethodName) :
     return StringHelper.isNotBlank(attributeOrMethodName) and (
         not attributeOrMethodName.startswith(f'{2 * c.UNDERSCORE}') and
@@ -148,10 +142,21 @@ def overrideSignatures(toOverride, original) :
     except Exception as exception :
         LogHelper.error(overrideSignatures,f'''failed to override signatures of {toOverride} by signatures of {original} method''',exception)
 
+def getName(thing, typeName=None) :
+    name = None
+    try :
+        name = thing.__name__
+    except :
+        if ObjectHelper.isNone(typeName) or StringHelper.isBlank(typeName) :
+            name = f'({NAME_NOT_PRESENT})'
+        else :
+            name = f'({typeName} {NAME_NOT_PRESENT})'
+    return name
+
 def printDetails(toDetail):
     print(f'{2 * c.TAB}printDetails({toDetail}):')
     try :
-        print(f'{2 * c.TAB}type({toDetail}).__name__ = {type(toDetail).__name__}')
+        print(f'{2 * c.TAB}type({toDetail}).__name__ = {getName(type(toDetail), typeName=UNKNOWN_TYPE_NAME)}')
     except :
         pass
     try :
@@ -163,11 +168,11 @@ def printDetails(toDetail):
     except :
         pass
     try :
-        print(f'{2 * c.TAB}type({toDetail}).__class__.__name__ = {type(toDetail).__class__.__name__}')
+        print(f'{2 * c.TAB}type({toDetail}).__class__.__name__ = {getName(type(toDetail).__class__, typeName=UNKNOWN_TYPE_NAME)}')
     except :
         pass
     try :
-        print(f'{2 * c.TAB}{toDetail}.__class__.__name__ = {toDetail.__class__.__name__}')
+        print(f'{2 * c.TAB}{toDetail}.__class__.__name__ = {getName(toDetail.__class__, typeName=UNKNOWN_TYPE_NAME)}')
     except :
         pass
     try :
@@ -182,7 +187,7 @@ def printDetails(toDetail):
 def printClass(instanceClass) :
     print(f'{2 * c.TAB}printClass({instanceClass}):')
     try :
-        print(f'{2 * c.TAB}{instanceClass}.__name__ = {instanceClass.__name__}')
+        print(f'{2 * c.TAB}{instanceClass}.__name__ = {getName(instanceClass, typeName=UNKNOWN_TYPE_NAME)}')
     except :
         pass
     try :
